==> 1.0.0.tar.gz: ios/Classes/sdk/network/TUApi.swift <==
//
//  TUApi.swift
//  test_wluper_sdk
//
//  Created by Alfonso Farruggia on 17/09/2021.
//

import Foundation
import UIKit


class TUApi {
    var _xapikey:String
    var base_url_understand = "https://zzlkqzn1kd.execute-api.eu-west-2.amazonaws.com/"
    var env = "staging/"
    var endpoint_understand = "true-understanding/understand"

    init(xapikey:String) {
        _xapikey = xapikey
    }

    func create_request(base_url:String, endpoint:String, method:String, xapikey:String)-> URLRequest {
        let url = URL(string: "\(base_url)\(env)\(endpoint)")!
        var request:URLRequest;
        request = URLRequest(url: url)
        request.httpMethod = method 
        request.allHTTPHeaderFields = [ "x-api-key": _xapikey ]
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        return request
    }
    
    public func understand(text:String) -> [String: Any] {
        var request = create_request(base_url:base_url_understand, endpoint:endpoint_understand, method:"POST",xapikey:self._xapikey)
        let semaphore = DispatchSemaphore(value: 0)
        var received:[String: Any]=["":""]
        let parameters: [String: Any] = [ "query": text ]
        let finalBody = try? JSONSerialization.data(withJSONObject: parameters)
        request.httpBody = finalBody
        
        let task = URLSession.shared.dataTask(with: request) { data, response, error in
            if let data = data {
                let json = try? JSONSerialization.jsonObject(with: data, options: []) as? [String: Any]
                if let json = json
                {
                    received = json
                }
            } else if let error = error {
                received = ["error":"HTTP Request Failed \(error)"]
            }
            semaphore.signal()
        }
        
        task.resume();
        semaphore.wait()
        return received;
        
    }
  
}

==> 1.1.0.tar.gz: ios/Classes/sdk/network/TUApi.swift <==
//
//  TUApi.swift
//  test_wluper_sdk
//
//  Created by Alfonso Farruggia on 17/09/2021.
//

import Foundation
import UIKit


class TUApi {
    var _xapikey:String
    var _clientid:String
    var base_url_understand = "https://trueunderstanding.wluperapi.com/v1/clients/"
    var endpoint_understand = "understand"

    init(clientid:String, xapikey:String) {
        _clientid = clientid
        _xapikey = xapikey
    }

    func create_request(base_url:String, endpoint:String, method:String)-> URLRequest {
        let url = URL(string: "\(base_url)\(_clientid)/\(endpoint)")!
        var request:URLRequest;
        request = URLRequest(url: url)
        request.httpMethod = method
        request.allHTTPHeaderFields = [ "x-api-key": _xapikey ]
        request.setValue("application/json", forHTTPHeaderField: "Accept")
        request.setValue("application/json", forHTTPHeaderField: "Content-Type")
        return request
    }

    public func understand(text:String) -> [String: Any] {
        var request = create_request(base_url:base_url_understand, endpoint:endpoint_understand, method:"POST")
        let semaphore = DispatchSemaphore(value: 0)
        var received:[String: Any]=["":""]
        let parameters: [String: Any] = [ "query": text ]
        let finalBody = try? JSONSerialization.data(withJSONObject: parameters)
        request.httpBody = finalBody

        let task = URLSession.shared.dataTask(with: request) { data, response, error in
            if let data = data {
                let json = try? JSONSerialization.jsonObject(with: data, options: []) as? [String: Any]
                if let json = json
                {
                    received = json
                }
            } else if let error = error {
                received = ["error":"HTTP Request Failed \(error)"]
            }
            semaphore.signal()
        }

        task.resume();
        semaphore.wait()
        return received;

    }

}
